@@ -7,6 +7,7 @@ import json
 import logging
 import os
 import urllib.parse
+from datetime import datetime
 from pathlib import Path
 from typing import Any, Final, Mapping, MutableMapping, cast
 
@@ -26,7 +27,7 @@ from ..exception import InvalidAPIParameters
 from ..types import SENTINEL
 from ..utils import CheckParamSource, check_params
 
-log = BraceStyleAdapter(logging.getLogger(__name__))
+log = BraceStyleAdapter(logging.getLogger(__spec__.name))  # type: ignore[name-defined]
 
 DEFAULT_CHUNK_SIZE: Final = 256 * 1024  # 256 KiB
 DEFAULT_INFLIGHT_CHUNKS: Final = 8
@@ -104,17 +105,27 @@ async def download(request: web.Request) -> web.StreamResponse:
                 else:
                     raise InvalidAPIParameters("The file is not a regular file.")
             if request.method == "HEAD":
+                ifrange: datetime | None = request.if_range
+                mtime = os.stat(file_path).st_mtime
+                last_mdt = datetime.fromtimestamp(mtime)
+                resp_status = 200
+                if ifrange is not None and mtime <= ifrange.timestamp():
+                    # Return partial content.
+                    resp_status = 206
                 return web.Response(
-                    status=200,
+                    status=resp_status,
                     headers={
                         hdrs.ACCEPT_RANGES: "bytes",
                         hdrs.CONTENT_LENGTH: str(file_path.stat().st_size),
+                        hdrs.LAST_MODIFIED: (
+                            f'{last_mdt.strftime("%a")}, {last_mdt.day} '
+                            f'{last_mdt.strftime("%b")} {last_mdt.year} '
+                            f"{last_mdt.hour}:{last_mdt.minute}:{last_mdt.second} GMT"
+                        ),
                     },
                 )
     ascii_filename = (
-        file_path.name.encode("ascii", errors="ignore")
-        .decode("ascii")
-        .replace('"', r"\"")
+        file_path.name.encode("ascii", errors="ignore").decode("ascii").replace('"', r"\"")
     )
     encoded_filename = urllib.parse.quote(file_path.name, encoding="utf-8")
     headers = {
@@ -176,9 +187,7 @@ async def download_directory_as_archive(
             # Include an empty directory in the archive as well.
             zf.write(root, Path(root).relative_to(file_path))
     ascii_filename = (
-        zip_filename.encode("ascii", errors="ignore")
-        .decode("ascii")
-        .replace('"', r"\"")
+        zip_filename.encode("ascii", errors="ignore").decode("ascii").replace('"', r"\"")
     )
     encoded_filename = urllib.parse.quote(zip_filename, encoding="utf-8")
     response = web.StreamResponse(
