@@ -5,9 +5,12 @@ from pathlib import Path, PurePosixPath
 from typing import Any, AsyncIterator, Mapping, Type
 
 from ai.backend.common.etcd import AsyncEtcd
+from ai.backend.storage.weka import WekaVolume
 
 from .abc import AbstractVolume
+from .cephfs import CephFSVolume
 from .exception import InvalidVolumeError
+from .gpfs import GPFSVolume
 from .netapp import NetAppVolume
 from .purestorage import FlashBladeVolume
 from .types import VolumeInfo
@@ -19,6 +22,9 @@ BACKENDS: Mapping[str, Type[AbstractVolume]] = {
     "vfs": BaseVolume,
     "xfs": XfsVolume,
     "netapp": NetAppVolume,
+    "weka": WekaVolume,
+    "spectrumscale": GPFSVolume,
+    "cephfs": CephFSVolume,
 }
 
 
